package com.jz.agent.utils;

import com.jz.agent.config.DmpDsAgentConstants;
import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.security.UserGroupInformation;

import java.io.IOException;
import java.sql.*;
import java.util.*;

public class JDBCUtils {
	
	public static Connection getConnections(String driver, String url, String user, String pwd) throws Exception {
		Connection conn = null;
		try {
			Properties props = new Properties();
			props.put("remarksReporting", "true");
			props.put("user", user);
			props.put("password", pwd);
			Class.forName(driver);
			conn = DriverManager.getConnection(url, props);
		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		}
		return conn;
	}

    public static void disconnect(Connection connection, ResultSet res, PreparedStatement ps) {
        try {
            if (res != null) res.close();
        } catch (SQLException e) {
            e.printStackTrace();
        }
        try {
            if (ps != null) ps.close();
        } catch (SQLException e) {
            e.printStackTrace();
        }
        try {
            if (connection != null) connection.close();
        } catch (SQLException e) {
            e.printStackTrace();
        }
    }
    
    public static void initKerberosENV4HDFS(Configuration conf) throws IOException {
        System.setProperty("java.security.krb5.conf", DmpDsAgentConstants.KERBEROS_CONFIGURATION_PATH);
        System.setProperty("javax.security.auth.useSubjectCredsOnly", "false");
        System.setProperty("sun.security.krb5.debug", "true");
        System.setProperty("HADOOP_USER_NAME", DmpDsAgentConstants.AGENT_HADOOP_USER_NAME);
        UserGroupInformation.setConfiguration(conf);
        UserGroupInformation.loginUserFromKeytab(
        		DmpDsAgentConstants.KERBEROS_KEYTAB_ACCOUNT_HDFS, DmpDsAgentConstants.KERBEROS_KEYTAB_PATH_HDFS
        		);
        System.out.println(UserGroupInformation.getCurrentUser());
    }
    
    public static void initKerberosENV4HIVE() throws IOException {
        System.setProperty("java.security.krb5.conf", DmpDsAgentConstants.KERBEROS_CONFIGURATION_PATH);
        System.setProperty("javax.security.auth.useSubjectCredsOnly", "false");
        System.setProperty("sun.security.krb5.debug", "true");
        
        Configuration conf = new Configuration();
        conf.set("hadoop.security.authentication" , "Kerberos");
        UserGroupInformation.setConfiguration(conf);
        UserGroupInformation.loginUserFromKeytab(
        		DmpDsAgentConstants.KERBEROS_KEYTAB_ACCOUNT_HIVE, DmpDsAgentConstants.KERBEROS_KEYTAB_PATH_HIVE
        		);
    }
    
    public static UserGroupInformation initKerberosENV4IMPALA() throws IOException {
        System.setProperty("java.security.krb5.conf", DmpDsAgentConstants.KERBEROS_CONFIGURATION_PATH);
        System.setProperty("javax.security.auth.useSubjectCredsOnly", "false");
        System.setProperty("sun.security.krb5.debug", "true");
        
        Configuration conf = new Configuration();
        conf.set("hadoop.security.authentication" , "Kerberos");
        UserGroupInformation.setConfiguration(conf);
        UserGroupInformation.loginUserFromKeytab(
        		DmpDsAgentConstants.KERBEROS_KEYTAB_ACCOUNT_IMPALA, DmpDsAgentConstants.KERBEROS_KEYTAB_PATH_IMPALA
        		);
        return UserGroupInformation.getLoginUser();
    }
    
    public static void initKerberosENV4KUDU() throws IOException {
    	System.setProperty("java.security.krb5.conf", DmpDsAgentConstants.KERBEROS_CONFIGURATION_PATH);
        System.setProperty("javax.security.auth.useSubjectCredsOnly", "false");
        System.setProperty("sun.security.krb5.debug", "true");
        
        Configuration conf = new Configuration();
        conf.set("hadoop.security.authentication" , "Kerberos");
        UserGroupInformation.setConfiguration(conf);
        UserGroupInformation.loginUserFromKeytab(
        		DmpDsAgentConstants.KERBEROS_KEYTAB_ACCOUNT_KUDU, DmpDsAgentConstants.KERBEROS_KEYTAB_PATH_KUDU
        		);
    }

    /**
     * 将结果集转换封装成Map,包含columns，rows，totalCount三个键；参数rowSize大于0为限定取得结果集条目（顺序）
     *
     * @param resultSet 源结果集
     * @param rowSize   取出结果集条目（顺序）
     * @return
     * @throws SQLException
     */
    public static Map<String, Object> convertResultSet2Map(ResultSet resultSet, int rowSize) throws SQLException {
        if (null == resultSet)
            return null;
        // 处理列
        ResultSetMetaData metaData = resultSet.getMetaData();
        int columnCount = metaData.getColumnCount();
        List<String> columnNameList = new ArrayList<>(columnCount);
        for (int i = 1; i <= columnCount; i++) {
            columnNameList.add(metaData.getColumnName(i));
        }
        // 处理行
        List<List<Object>> allColumnValueList = new ArrayList<>();
        List<Object> rowColumnValueList;
        int count = 0;
        while (resultSet.next()) {
            rowColumnValueList = new ArrayList<>();
            for (int i = 1; i <= columnCount; i++) {
                rowColumnValueList.add(resultSet.getObject(i));
            }
            allColumnValueList.add(rowColumnValueList);
            count++;
            if (rowSize > 0 && count == rowSize) {
                break;
            }
        }

        Map<String, Object> returnDataMap = new HashMap<>();
        returnDataMap.put("columns", columnNameList);
        returnDataMap.put("rows", allColumnValueList);
        returnDataMap.put("totalCount", allColumnValueList.size());
        return returnDataMap;
    }

}
