package com.jz.dmp.modules.controller.projconfig;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.jz.common.annotation.MethodCallLogPrint;
import com.jz.common.bean.BaseBeanResponse;
import com.jz.common.constant.StatuConstant;
import com.jz.dmp.modules.controller.projconfig.bean.DmpComputEngineDto;
import com.jz.dmp.modules.controller.projconfig.bean.DmpComputEngineRequest;
import com.jz.dmp.modules.controller.projconfig.bean.DmpPublicConfigInfoDto;
import com.jz.dmp.modules.controller.projconfig.bean.DmpPublicConfigInfoRequest;
import com.jz.dmp.modules.model.DmpPublicConfigInfo;
import com.jz.dmp.modules.service.projconfig.DmpComputEngineService;
import com.jz.dmp.modules.service.projconfig.DmpPublicConfigInfoService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * 公共配置表Controller
 * @author ybz
 *
 */
@RestController
@RequestMapping("/dmp/public/config/info")
@Api(tags = "公共配置表")
public class DmpPublicConfigInfoController {
	
	@Autowired
	private DmpPublicConfigInfoService dmpPublicConfigInfoService;
	
	@Autowired
	private DmpComputEngineService dmpComputEngineService;
	
	/**列表查询计算引擎表
	 * @param dmpComputEngineRequest
	 * @return
	 */
	@MethodCallLogPrint
	@RequestMapping(method = RequestMethod.POST, value = "/findList")
	@ApiOperation(value = "列表查询计算引擎表", notes = "列表查询计算引擎表")
	public BaseBeanResponse<DmpComputEngineDto> findList(@RequestBody DmpComputEngineRequest dmpComputEngineRequest, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpComputEngineDto> baseBeanResponse = new BaseBeanResponse<DmpComputEngineDto>();
		try {
			baseBeanResponse = dmpComputEngineService.findList(dmpComputEngineRequest, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("查询失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**新增或修改公共配置表
	 * @param dmpPublicConfigInfoRequest
	 * @return
	 */
	@MethodCallLogPrint
	@RequestMapping(method = RequestMethod.POST, value = "/addOrEdit")
	@ApiOperation(value = "新增或修改公共配置表", notes = "新增或修改公共配置表")
	public BaseBeanResponse<DmpPublicConfigInfo> addOrEdit(@RequestBody DmpPublicConfigInfo dmpPublicConfigInfo, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpPublicConfigInfo> baseBeanResponse = new BaseBeanResponse<DmpPublicConfigInfo>();
		try {
			baseBeanResponse = dmpPublicConfigInfoService.addOrEdit(dmpPublicConfigInfo, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("新增或修改失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**查询公共配置
	 * @param dmpPublicConfigInfoRequest
	 * @return
	 */
	@MethodCallLogPrint
	@RequestMapping(method = RequestMethod.GET, value = "/findOne")
	@ApiOperation(value = "查询公共配置", notes = "查询公共配置")
	public BaseBeanResponse<DmpPublicConfigInfoDto> findOne(HttpServletRequest httpRequest){
		BaseBeanResponse<DmpPublicConfigInfoDto> baseBeanResponse = new BaseBeanResponse<DmpPublicConfigInfoDto>();
		try {
			baseBeanResponse = dmpPublicConfigInfoService.findOne(httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("查询失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
}
