package com.jz.dmp.modules.service.impl;

import com.jz.common.constant.JsonResult;
import com.jz.dmp.modules.dao.DmpSyncingDatasourceTypeDao;
import com.jz.dmp.modules.model.DmpSyncingDatasourceType;
import com.jz.dmp.modules.service.DmpSyncingDatasourceTypeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 数据源类型(DmpSyncingDatasourceType)表服务实现类
 *
 * @author Bellamy
 * @since 2020-12-29 19:24:05
 */
@Service("dmpSyncingDatasourceTypeService")
public class DmpSyncingDatasourceTypeServiceImpl implements DmpSyncingDatasourceTypeService {
    @Autowired
    private DmpSyncingDatasourceTypeDao dmpSyncingDatasourceTypeDao;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @Override
    public DmpSyncingDatasourceType queryById(Integer id) {
        return this.dmpSyncingDatasourceTypeDao.queryById(id);
    }

    /**
     * 查询多条数据
     *
     * @param offset 查询起始位置
     * @param limit  查询条数
     * @return 对象列表
     */
    @Override
    public List<DmpSyncingDatasourceType> queryAllByLimit(int offset, int limit) {
        return this.dmpSyncingDatasourceTypeDao.queryAllByLimit(offset, limit);
    }

    /**
     * 新增数据
     *
     * @param dmpSyncingDatasourceType 实例对象
     * @return 实例对象
     */
    @Override
    public DmpSyncingDatasourceType insert(DmpSyncingDatasourceType dmpSyncingDatasourceType) {
        this.dmpSyncingDatasourceTypeDao.insert(dmpSyncingDatasourceType);
        return dmpSyncingDatasourceType;
    }

    /**
     * 修改数据
     *
     * @param dmpSyncingDatasourceType 实例对象
     * @return 实例对象
     */
    @Override
    public DmpSyncingDatasourceType update(DmpSyncingDatasourceType dmpSyncingDatasourceType) {
        this.dmpSyncingDatasourceTypeDao.update(dmpSyncingDatasourceType);
        return this.queryById(dmpSyncingDatasourceType.getId());
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Integer id) {
        return this.dmpSyncingDatasourceTypeDao.deleteById(id) > 0;
    }

    /**
     * 获取数据源——下拉框
     *
     * @return
     * @author Bellamy
     * @since 2021-01-21
     */
    @Override
    public JsonResult queryDatasourceList() throws Exception {
        Map params = new HashMap<>();
        List<DmpSyncingDatasourceType> list = dmpSyncingDatasourceTypeDao.queryAllByParams(params);
        return JsonResult.ok(list);
    }
}